==> ews-1.0.2.tar.gz: lib/ComplexProperties/Recurrence/Ranges/NoEndRecurrenceRange.dart <==
/*
 * Exchange Web Services Managed API
 *
 * Copyright (c) Microsoft Corporation
 * All rights reserved.
 *
 * MIT License
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this
 * software and associated documentation files (the "Software"), to deal in the Software
 * without restriction, including without limitation the rights to use, copy, modify, merge,
 * publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons
 * to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or
 * substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED *AS IS*, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
 * INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

import 'package:ews/ComplexProperties/Recurrence/Patterns/Recurrence.dart';
import 'package:ews/ComplexProperties/Recurrence/Ranges/RecurrenceRange.dart';
import 'package:ews/Core/XmlElementNames.dart';

/// <summary>
/// Represents recurrence range with no end date.
/// </summary>
class NoEndRecurrenceRange extends RecurrenceRange {
  /// <summary>
  /// Initializes a new instance of the <see cref="NoEndRecurrenceRange"/> class.
  /// </summary>
  NoEndRecurrenceRange() : super();

  /// <summary>
  /// Initializes a new instance of the <see cref="NoEndRecurrenceRange"/> class.
  /// </summary>
  /// <param name="startDate">The start date.</param>
  NoEndRecurrenceRange.withStartDate(DateTime startDate) : super.withStartDate(startDate);

  /// <summary>
  /// Gets the name of the XML element.
  /// </summary>
  /// <value>The name of the XML element.</value>
  @override
  String get XmlElementName => XmlElementNames.NoEndRecurrence;

  /// <summary>
  /// Setups the recurrence.
  /// </summary>
  /// <param name="recurrence">The recurrence.</param>
  @override
  void SetupRecurrence(Recurrence recurrence) {
    super.SetupRecurrence(recurrence);

    recurrence.NeverEnds();
  }
}

==> ews-1.0.20.tar.gz: lib/ComplexProperties/Recurrence/Ranges/NoEndRecurrenceRange.dart <==
/*
 * Exchange Web Services Managed API
 *
 * Copyright (c) Microsoft Corporation
 * All rights reserved.
 *
 * MIT License
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this
 * software and associated documentation files (the "Software"), to deal in the Software
 * without restriction, including without limitation the rights to use, copy, modify, merge,
 * publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons
 * to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or
 * substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED *AS IS*, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
 * INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

import 'package:ews/ComplexProperties/Recurrence/Patterns/Recurrence.dart';
import 'package:ews/ComplexProperties/Recurrence/Ranges/RecurrenceRange.dart';
import 'package:ews/Core/XmlElementNames.dart';

/// <summary>
/// Represents recurrence range with no end date.
/// </summary>
class NoEndRecurrenceRange extends RecurrenceRange {
  /// <summary>
  /// Initializes a new instance of the <see cref="NoEndRecurrenceRange"/> class.
  /// </summary>
  NoEndRecurrenceRange() : super();

  /// <summary>
  /// Initializes a new instance of the <see cref="NoEndRecurrenceRange"/> class.
  /// </summary>
  /// <param name="startDate">The start date.</param>
  NoEndRecurrenceRange.withStartDate(DateTime startDate)
      : super.withStartDate(startDate);

  /// <summary>
  /// Gets the name of the XML element.
  /// </summary>
  /// <value>The name of the XML element.</value>
  @override
  String get XmlElementName => XmlElementNames.NoEndRecurrence;

  /// <summary>
  /// Setups the recurrence.
  /// </summary>
  /// <param name="recurrence">The recurrence.</param>
  @override
  void SetupRecurrence(Recurrence recurrence) {
    super.SetupRecurrence(recurrence);

    recurrence.NeverEnds();
  }
}
